# Azure Datalake Utils


[![pypi](https://img.shields.io/pypi/v/azure_datalake_utils.svg)](https://pypi.org/project/azure_datalake_utils/)
[![python](https://img.shields.io/pypi/pyversions/azure_datalake_utils.svg)](https://pypi.org/project/azure_datalake_utils/)
[![Build Status](https://github.com/centraal_api/azure_datalake_utils/actions/workflows/dev.yml/badge.svg)](https://github.com/centraal_api/azure_datalake_utils/actions/workflows/dev.yml)
[![codecov](https://codecov.io/gh/centraal_api/azure_datalake_utils/branch/main/graphs/badge.svg)](https://codecov.io/github/centraal_api/azure_datalake_utils)



Utilidades para interactuar con Azure Datalake


* Documentation: <https://centraal_api.github.io/azure_datalake_utils>
* GitHub: <https://github.com/centraal_api/azure_datalake_utils>
* PyPI: <https://pypi.org/project/azure_datalake_utils/>
* Free software: Apache-2.0


## Features

* TODO

## Credits

This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the [waynerv/cookiecutter-pypackage](https://github.com/waynerv/cookiecutter-pypackage) project template.
